#
# Copyright (c) 2015 Midokura SARL, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from charmhelpers.core import hookenv
from charmhelpers.core.services import helpers


class MidonetApiRelation(helpers.RelationContext):
    name = 'midonet-api'
    interface = 'midonet'
    port = 8080

    def __init__(self, *args, **kwargs):
        self.required_keys = ['host', 'port']
        helpers.RelationContext.__init__(self, *args, **kwargs)

    def provide_data(self):
        return {
            'host': hookenv.unit_get('private-address'),
            'port': self.port,
        }


class KeystoneAdminRelation(helpers.RelationContext):
    name = 'keystone'
    interface = 'keystone-admin'

    def __init__(self, *args, **kwargs):
        self.required_keys = ['service_hostname', 'service_port',
                              'service_username', 'service_tenant_name',
                              'service_region', 'service_password']
        helpers.RelationContext.__init__(self, *args, **kwargs)


class ZookeeperRelation(helpers.RelationContext):
    name = 'zookeeper'
    interface = 'zookeeper'

    def __init__(self, *args, **kwargs):
        self.required_keys = ['private-address', 'port']
        helpers.RelationContext.__init__(self, *args, **kwargs)


class RepositoryRelation(helpers.RelationContext):
    name = 'repository'
    interface = 'midonet-repository'
    # The keys are not required since we'll get the puppet defaults if not
    # set.
