#
# Copyright (c) 2015 Midokura SARL, All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import os

from charmhelpers.core import hookenv
from charmhelpers.core.services import base
from charmhelpers.core.services import helpers
from midonet_helpers import puppet
from midonet_helpers import relations as common_relations
from midonet_helpers import repositories
import relations

ROOTWRAP_PATH = '/etc/nova/rootwrap.d'


def manage():
    cfg = hookenv.config()
    manager = base.ServiceManager([
        {
            'service': 'midolman',
            'ports': [],
            'provided_data': [],
            'required_data': [relations.CassandraRelation(),
                              common_relations.ZookeeperRelation(),
                              repositories.config(cfg['midonet-release'],
                                                  cfg.get('mem-username'),
                                                  cfg.get('mem-password'))],
            'data_ready': [
                _write_rootwrap,
                helpers.render_template(
                    source='common.yaml',
                    target='/var/lib/hiera/midonet_agent/common.yaml'),
                puppet.InstallCallback('midonet::midonet_agent'),
            ],
        },
    ])
    manager.manage()


def _write_rootwrap(*args, **kwargs):
    """Write MidoNet's rootwrap when running on  a compute node."""
    if os.path.exists(ROOTWRAP_PATH):
        with open(os.path.join(ROOTWRAP_PATH, 'midonet.filters'), 'w') as filt:
            filt.write('[Filters]\nmm-ctl: CommandFilter, mm-ctl, root')
